package com.atguigu.lease.web.admin.service.impl;

import com.atguigu.lease.common.result.ResultCodeEnum;
import com.atguigu.lease.model.entity.*;
import com.atguigu.lease.model.enums.ItemType;
import com.atguigu.lease.web.admin.mapper.*;
import com.atguigu.lease.web.admin.service.*;
import com.atguigu.lease.web.admin.vo.apartment.ApartmentDetailVo;
import com.atguigu.lease.web.admin.vo.apartment.ApartmentItemVo;
import com.atguigu.lease.web.admin.vo.apartment.ApartmentQueryVo;
import com.atguigu.lease.web.admin.vo.apartment.ApartmentSubmitVo;
import com.atguigu.lease.web.admin.vo.fee.FeeValueVo;
import com.atguigu.lease.web.admin.vo.graph.GraphVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author liubo
 * @description 针对表【apartment_info(公寓信息表)】的数据库操作Service实现
 * @createDate 2023-07-24 15:48:00
 */
@Service
public class ApartmentInfoServiceImpl extends ServiceImpl<ApartmentInfoMapper, ApartmentInfo>
        implements ApartmentInfoService {

    //注入公寓基本信息的Mapper
    @Autowired
    private ApartmentInfoMapper apartmentInfoMapper;
    //注入其他四个相关表的Service 在里面用表

    //公寓基础数据
    @Autowired
    private GraphInfoService graphInfoService;
    //公寓标签
    @Autowired
    private ApartmentLabelService apartmentLabelService;
    //公寓费用
    @Autowired
    private ApartmentFeeValueService apartmentFeeValueService;
    //公寓设施
    @Autowired
    private ApartmentFacilityService apartmentFacilityService;
    @Autowired
    private FacilityInfoMapper facilityInfoMapper;
    @Autowired
    private LabelInfoMapper labelInfoMapper;

    @Autowired
    private FeeValueMapper feeValueMapper;
    @Autowired
    private GraphInfoMapper graphInfoMapper;
    @Autowired
    private RoomInfoMapper roomInfoMapper;


    @Override
    public void saveOrUpdateApartment(ApartmentSubmitVo apartmentSubmitVo) {

        //判定一下id有没有 如果为空的话就是添加,不为空就是修改
        //修改的话就先删除其他的已经存储的代码 再次用内部的数据去修改
        boolean b = apartmentSubmitVo.getId() != null;
        this.saveOrUpdate(apartmentSubmitVo);
        //修改的时候就删除数据库中储存的代码
        if(b){
            //
            LambdaQueryWrapper<ApartmentFacility> wrapperApartmentFacility
                    = new LambdaQueryWrapper<>();
            wrapperApartmentFacility.eq(ApartmentFacility::getApartmentId,apartmentSubmitVo.getId());
            apartmentFacilityService.remove(wrapperApartmentFacility);

            LambdaQueryWrapper<ApartmentFeeValue> wrapperApartmentFeeValue
                    = new LambdaQueryWrapper<>();
            wrapperApartmentFeeValue.eq(ApartmentFeeValue::getApartmentId,
                    apartmentSubmitVo.getId());
            apartmentFeeValueService.remove(wrapperApartmentFeeValue);

            LambdaQueryWrapper<ApartmentLabel> wrapperApartmentLabel
                    = new LambdaQueryWrapper<>();
            wrapperApartmentLabel.eq(ApartmentLabel::getApartmentId,
                    apartmentSubmitVo.getId());
            apartmentLabelService.remove(wrapperApartmentLabel);

            LambdaQueryWrapper<GraphInfo> wrapper = new LambdaQueryWrapper<>();
            wrapper.eq(GraphInfo::getItemId,apartmentSubmitVo.getId());
            wrapper.eq(GraphInfo::getItemType, ItemType.APARTMENT);
            graphInfoService.remove(wrapper);
        }
//        一个公寓id 对应多个配套数据，添加多条记录

        List<Long> facilityInfoIds = apartmentSubmitVo.getFacilityInfoIds();
        if(!CollectionUtils.isEmpty(facilityInfoIds)) {
            List<ApartmentFacility> afList = new ArrayList<>();
            for (Long facilityInfoId : facilityInfoIds){
                //创建apartmentFacility对象，向设置需要添加值
                ApartmentFacility apartmentFacility = new ApartmentFacility();
                //设置配套数据id
                apartmentFacility.setFacilityId(facilityInfoId);
                //设置公寓id
                apartmentFacility.setApartmentId(apartmentSubmitVo.getId());
                //放到集合
                afList.add(apartmentFacility);
            }
            apartmentFacilityService.saveBatch(afList);

    }

        List<Long> feeValueIds = apartmentSubmitVo.getFeeValueIds();
        if(!CollectionUtils.isEmpty(feeValueIds)){
            List<ApartmentFeeValue> afvList = new ArrayList<>();
            for (Long feeValueId : feeValueIds) {
                ApartmentFeeValue apartmentFeeValue = new ApartmentFeeValue();
                apartmentFeeValue.setApartmentId(apartmentSubmitVo.getId());
                apartmentFeeValue.setFeeValueId(feeValueId);
                afvList.add(apartmentFeeValue);
            }
            apartmentFeeValueService.saveBatch(afvList);
        }

        List<Long> labelIds = apartmentSubmitVo.getLabelIds();
        if(!CollectionUtils.isEmpty(labelIds)){
            List<ApartmentLabel> alList = new ArrayList<>();
            for (Long labelId : labelIds) {
                ApartmentLabel apartmentLabel = new ApartmentLabel();
                apartmentLabel.setApartmentId(apartmentSubmitVo.getId());
                apartmentLabel.setLabelId(labelId);
                alList.add(apartmentLabel);
            }
            apartmentLabelService.saveBatch(alList);

        }
        List<GraphVo> graphVoList = apartmentSubmitVo.getGraphVoList();
        if(!CollectionUtils.isEmpty(graphVoList)){
            List<GraphInfo> list = new ArrayList<>();
            for (GraphVo graphVo : graphVoList) {
                GraphInfo graphInfo = new GraphInfo();
                graphInfo.setItemId(apartmentSubmitVo.getId());
                graphInfo.setItemType(ItemType.APARTMENT);
                graphInfo.setName(graphVo.getName());
                graphInfo.setUrl(graphVo.getUrl());
                list.add(graphInfo);
            }
            graphInfoService.saveBatch(list);
        }
    }

    @Override
    public ApartmentDetailVo getDetailById(Long id) {
        ApartmentInfo apartmentInfo = this.getById(id);
        if (apartmentInfo == null) {
            return null;
        }
        List<FacilityInfo> facilityListByApartmentId = facilityInfoMapper.findFacilityListByApartmentId(id);
        List<LabelInfo> labelListByApartmentId = labelInfoMapper.findLabelListByApartmentId(id);
        List<FeeValueVo> labelListByApartmentId1 = feeValueMapper.findLabelListByApartmentId(id);
        List<GraphVo> graphInfos = graphInfoMapper.selectGraphListByApartmentId(ItemType.APARTMENT, id);
        ApartmentDetailVo apartmentDetailVo = new ApartmentDetailVo();
        BeanUtils.copyProperties(apartmentInfo,apartmentDetailVo);

        apartmentDetailVo.setFacilityInfoList(facilityListByApartmentId);
        apartmentDetailVo.setLabelInfoList(labelListByApartmentId);
        apartmentDetailVo.setFeeValueVoList(labelListByApartmentId1);
        apartmentDetailVo.setGraphVoList(graphInfos);
        return apartmentDetailVo;


    }

    @Override
    public IPage<ApartmentItemVo> selectApartmentInfoPage(Page<ApartmentItemVo> page, ApartmentQueryVo queryVo) {
        IPage<ApartmentItemVo> apartmentItemVoIPage = apartmentInfoMapper.selectApartmentInfoPage(page, queryVo);
        return apartmentItemVoIPage;
    }

    @Override
    public void removeApartmentById(Long id) {
        //先判断是否有房间 有房间了不能删
        //条件判断:看有没有房间
        LambdaUpdateWrapper<RoomInfo> wrapper = new LambdaUpdateWrapper<>();
        wrapper.eq(RoomInfo::getApartmentId,id);
        //看看有没有房间 有了就提示信息
        Long l = roomInfoMapper.countRoomMany();
        if (l > 0){
            throw new RuntimeException("存在房间信息，不能删除");
        }
        //删除
        this.removeById(id);
        //删除配套信息
        LambdaQueryWrapper<ApartmentFacility> wrapper1
                = new LambdaQueryWrapper<>();
        wrapper1.eq(ApartmentFacility::getApartmentId,id);
        apartmentFacilityService.remove(wrapper1);

        //删除标签信息
        LambdaQueryWrapper<ApartmentLabel> wrapper2
                = new LambdaQueryWrapper<>();
        wrapper2.eq(ApartmentLabel::getApartmentId,id);
        apartmentLabelService.remove(wrapper2);

        //删除杂费信息
        LambdaQueryWrapper<ApartmentFeeValue> wrapper3
                = new LambdaQueryWrapper<>();
        wrapper3.eq(ApartmentFeeValue::getApartmentId,id);
        apartmentFeeValueService.remove(wrapper3);

        //删除图片信息
        LambdaQueryWrapper<GraphInfo> wrapper4
                = new LambdaQueryWrapper<>();
        wrapper4.eq(GraphInfo::getItemId,id);
        wrapper4.eq(GraphInfo::getItemType,ItemType.APARTMENT);
        graphInfoService.remove(wrapper4);



    }

}




